#
# spec file for package pagure
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2021 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Prevent dep generators from trying to process static stuff and stall out
# We only need to read the python metadata anyway
%global __provides_exclude_from ^%{python3_sitelib}/pagure/.*$
%global __requires_exclude_from ^%{python3_sitelib}/pagure/.*$

Name:           pagure
Version:        5.13.3
Release:        1.7
Summary:        A git-centered forge
Group:          Development/Tools/Version Control
# Pagure itself is GPL-2.0-or-later; flask_fas_openid.py is LGPL-2.1-or-later
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://pagure.io/pagure
Source0:        https://pagure.io/releases/pagure/%{name}-%{version}.tar.gz

# Vendor in the single file from python-fedora that's needed
# This way, we avoid having to pull in all of python-fedora
# This file is licensed LGPL-2.1-or-later, per https://github.com/fedora-infra/python-fedora/blob/develop/README.rst#license
Source1:        https://raw.githubusercontent.com/fedora-infra/python-fedora/4719f10b3af1cf068e969387eab7df7e935003cd/flask_fas_openid.py

# SUSE-specific README providing a quickstart guide
Source10:       pagure-README.SUSE

# Backports from upstream

# SUSE-specific fixes
## Change the defaults in the example config to match packaging
Patch1000:      pagure-5.0-default-example-cfg.patch

BuildArch:      noarch


BuildRequires:  apache2
BuildRequires:  fdupes
BuildRequires:  nginx
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  systemd-rpm-macros

BuildRequires:  python3-Flask
BuildRequires:  python3-Flask-WTF
BuildRequires:  python3-Markdown
BuildRequires:  python3-Pillow
BuildRequires:  python3-alembic
BuildRequires:  python3-arrow
BuildRequires:  python3-bcrypt
BuildRequires:  python3-binaryornot
BuildRequires:  python3-bleach
BuildRequires:  python3-blinker
BuildRequires:  python3-chardet
BuildRequires:  python3-cryptography
BuildRequires:  python3-docutils
BuildRequires:  python3-email_validator
BuildRequires:  python3-psutil
BuildRequires:  python3-pygit2 >= 0.26.0
#BuildRequires:      python3-fedora-flask
BuildRequires:  python3-python3-openid
BuildRequires:  python3-SQLAlchemy >= 0.8
BuildRequires:  python3-WTForms
BuildRequires:  python3-munch
BuildRequires:  python3-python-openid-cla
BuildRequires:  python3-python-openid-teams
BuildRequires:  python3-redis
BuildRequires:  python3-straight-plugin
BuildRequires:  python3-whitenoise

# We require OpenSSH 7.4+ for SHA256 support
Requires:       openssh >= 7.4

Requires:       python3-Flask
Requires:       python3-Flask-WTF
Requires:       python3-Markdown
Requires:       python3-Pillow
Requires:       python3-alembic
Requires:       python3-arrow
Requires:       python3-bcrypt
Requires:       python3-binaryornot
Requires:       python3-bleach
Requires:       python3-blinker
Requires:       python3-celery
Requires:       python3-chardet
Requires:       python3-cryptography
Requires:       python3-docutils
Requires:       python3-email_validator
Requires:       python3-psutil
Requires:       python3-pygit2 >= 0.26.0
#Requires:           python3-fedora-flask
Requires:       python3-python3-openid
Requires:       python3-SQLAlchemy > 0.8
Requires:       python3-WTForms
Requires:       python3-munch
Requires:       python3-python-openid-cla
Requires:       python3-python-openid-teams
Requires:       python3-redis
Requires:       python3-straight-plugin
Requires:       python3-whitenoise

# Required for celery
Requires:       python3-pytz

# Required for database setup/migrations
Requires:       python3-dbm
Requires:       python3-kitchen
Requires:       python3-requests

# We want to use cchardet whenever it's available
Recommends:     python3-cchardet

# If using PostgreSQL, the correct driver should be installed
Recommends:     (python3-psycopg2 if postgresql-server)

# If using MariaDB/MySQL, the correct driver should be installed
Recommends:     (python3-PyMySQL if mysql-server)

# If using Apache web server, the correct configuration should be installed
Recommends:     (%{name}-web-apache-httpd if apache2)

# If using Nginx web server, the correct configuration should be installed
Recommends:     (%{name}-web-nginx if nginx)

# The default theme is required
Requires:       %{name}-theme-default

%{?systemd_ordering}

# We use the git tools for some actions due to deficiencies in libgit2 and pygit2
Requires:       git-core

# No dependency of the app per se, but required to make it working.
OrderWithRequires:  gitolite >= 3.0
Requires(pre):  gitolite >= 3.0
Requires:       gitolite >= 3.0
Requires(post): user(wwwrun)

%description
Pagure is a git-centered forge based on pygit2.

Currently, Pagure offers a web-interface for git repositories, a ticket
system and possibilities to create new projects, fork existing ones and
create/merge pull-requests across or within projects.

For steps on how to set up the system after installing this package,
please read %{_docdir}/%{name}/README.SUSE.

%package            web-apache-httpd
Summary:        Apache HTTPD configuration for Pagure
Requires:       %{name} = %{version}-%{release}
Requires:       apache2-mod_wsgi-python3
# Apache config moved out to its own subpackage
Obsoletes:      %{name} < 5.10
Conflicts:      %{name} < 5.10

%description        web-apache-httpd
This package provides the configuration files for deploying
a Pagure server using the Apache HTTPD server.

%package            web-nginx
Summary:        Nginx configuration for Pagure
Requires:       %{name} = %{version}-%{release}
Requires:       nginx
Requires:       python3-gunicorn

%description        web-nginx
This package provides the configuration files for deploying
a Pagure server using the Nginx web server.

%package            theme-upstream
Summary:        Base theme for the Pagure web interface
Requires:       %{name} = %{version}-%{release}

%description        theme-upstream
This package provides the web interface assets for styling
a Pagure server with the base upstream look and feel.

%package            theme-pagureio
Summary:        Pagure web interface theme used on Pagure.io
Requires:       %{name} = %{version}-%{release}

%description        theme-pagureio
This package provides the web interface assets for styling
a Pagure server with the same look and feel as Pagure.io.

%package            theme-srcfpo
Summary:        Pagure web interface theme used on src.fedoraproject.org
Requires:       %{name} = %{version}-%{release}

%description        theme-srcfpo
This package provides the web interface assets for styling
a Pagure server with the same look and feel as src.fedoraproject.org.

%package            theme-chameleon
Summary:        Pagure web interface theme based on openSUSE's chameleon theme
Requires:       %{name} = %{version}-%{release}

%description        theme-chameleon
This package provides the web interface assets for styling
a Pagure server with the same look and feel as openSUSE Infrastructure.

%package            theme-default-upstream
Summary:        Configuration for pagure to default to the upstream web interface theme
Conflicts:      %{name}-theme-default
Provides:       %{name}-theme-default
Requires:       %{name}-theme-upstream = %{version}-%{release}

%description        theme-default-upstream
This package sets the default web interface assets used for
a Pagure server running as shipped by upstream.

%package            theme-default-openSUSE
Summary:        Configuration for pagure to default to the openSUSE web interface theme
Conflicts:      %{name}-theme-default
Provides:       %{name}-theme-default
Requires:       %{name}-theme-chameleon = %{version}-%{release}
Enhances:       (%{name} and branding-openSUSE)
Removepathpostfixes:.openSUSE

%description        theme-default-openSUSE
This package sets the default web interface assets used for
a Pagure server running on openSUSE.

%package            milters
Summary:        Milter to integrate pagure with emails
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
Requires:       python3-pymilter
%{?systemd_requires}
# It would work with sendmail but we configure things (like the tempfile)
# to work with postfix
Requires:       postfix

%description        milters
Milters (Mail filters) allowing the integration of pagure and emails.
This is useful for example to allow commenting on a ticket by email.

%package            ev
Summary:        EventSource server for pagure
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
Requires:       python3-Trololio
%{?systemd_requires}

%description        ev
Pagure comes with an eventsource server allowing live update of the pages
supporting it. This package provides it.

%package            webhook
Summary:        Web-Hook server for pagure
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
%{?systemd_requires}

%description        webhook
Pagure comes with an webhook server allowing http callbacks for any action
done on a project. This package provides it.

%package            ci
Summary:        A CI service for pagure
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
Requires:       python3-python-jenkins
%{?systemd_requires}

%description        ci
Pagure comes with a continuous integration service, currently supporting
only jenkins but extendable to others.
With this service, your CI server will be able to report the results of the
build on the pull-requests opened to your project.

%package            logcom
Summary:        The logcom service for pagure
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
%{?systemd_requires}

%description        logcom
pagure-logcom contains the service that logs commits into the database so that
the activity calendar heatmap is filled.

%package            loadjson
Summary:        The loadjson service for pagure
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
%{?systemd_requires}

%description        loadjson
pagure-loadjson is the service allowing to update the database with the
information provided in the JSON blobs that are stored in the tickets (and
in the future pull-requests) git repo.

%package            mirror
Summary:        The mirroring service for pagure
BuildRequires:  systemd-rpm-macros
Requires:       %{name} = %{version}-%{release}
%{?systemd_requires}

%description        mirror
pagure-mirror is the service mirroring projects that asked for it outside
of this pagure instance.

%prep
%autosetup -p1

# Vendor in the file needed from python-fedora
install -pm 0644 %{SOURCE1} pagure/ui
sed -e "s/import flask_fas_openid/from pagure.ui import flask_fas_openid as flask_fas_openid/" -i pagure/ui/fas_login.py

# Install README.SUSE file
install -pm 0644 %{SOURCE10} README.SUSE

%build
%py3_build

%install
%py3_install

# Install apache configuration file
mkdir -p %{buildroot}/%{_sysconfdir}/apache2/vhosts.d
install -p -m 644 files/pagure-apache-httpd.conf %{buildroot}/%{_sysconfdir}/apache2/vhosts.d/pagure.conf

# Install nginx configuration file
mkdir -p %{buildroot}/%{_sysconfdir}/nginx/vhosts.d/
install -p -m 644 files/pagure-nginx.conf %{buildroot}/%{_sysconfdir}/nginx/vhosts.d/pagure.conf

# Install configuration file
mkdir -p %{buildroot}/%{_sysconfdir}/pagure
install -p -m 644 files/pagure.cfg.sample %{buildroot}/%{_sysconfdir}/pagure/pagure.cfg

# Install WSGI file
mkdir -p %{buildroot}/%{_datadir}/pagure
install -p -m 644 files/pagure.wsgi %{buildroot}/%{_datadir}/pagure/pagure.wsgi
install -p -m 644 files/doc_pagure.wsgi %{buildroot}/%{_datadir}/pagure/doc_pagure.wsgi

# Install the createdb script
install -p -m 644 createdb.py %{buildroot}/%{_datadir}/pagure/pagure_createdb.py

# Install the api_key_expire_mail.py script
install -p -m 644 files/api_key_expire_mail.py %{buildroot}/%{_datadir}/pagure/api_key_expire_mail.py

# Install the mirror_project_in.py script
install -p -m 644 files/mirror_project_in.py %{buildroot}/%{_datadir}/pagure/mirror_project_in.py

# Install the keyhelper and aclcheck scripts
mkdir -p %{buildroot}/%{_libexecdir}/pagure
install -p -m 755 files/aclchecker.py %{buildroot}/%{_libexecdir}/pagure/aclchecker.py
install -p -m 755 files/keyhelper.py %{buildroot}/%{_libexecdir}/pagure/keyhelper.py

# Install the alembic configuration file
install -p -m 644 files/alembic.ini %{buildroot}/%{_sysconfdir}/pagure/alembic.ini

# Install the alembic revisions
cp -r alembic %{buildroot}/%{_datadir}/pagure

# Install the systemd file for the web frontend
mkdir -p %{buildroot}/%{_unitdir}
install -p -m 644 files/pagure_web.service \
    %{buildroot}/%{_unitdir}/pagure_web.service

# Install the systemd file for the docs web frontend
mkdir -p %{buildroot}/%{_unitdir}
install -p -m 644 files/pagure_docs_web.service \
    %{buildroot}/%{_unitdir}/pagure_docs_web.service

# Install the systemd file for the worker
mkdir -p %{buildroot}/%{_unitdir}
install -p -m 644 files/pagure_worker.service \
    %{buildroot}/%{_unitdir}/pagure_worker.service

# Install the systemd file for the authorized_keys worker
install -p -m 644 files/pagure_authorized_keys_worker.service \
    %{buildroot}/%{_unitdir}/pagure_authorized_keys_worker.service

# Install the systemd file for the gitolite worker
install -p -m 644 files/pagure_gitolite_worker.service \
    %{buildroot}/%{_unitdir}/pagure_gitolite_worker.service

# Install the systemd file for the web-hook
install -p -m 644 files/pagure_webhook.service \
    %{buildroot}/%{_unitdir}/pagure_webhook.service

# Install the systemd file for the ci service
install -p -m 644 files/pagure_ci.service \
    %{buildroot}/%{_unitdir}/pagure_ci.service

# Install the systemd file for the logcom service
install -p -m 644 files/pagure_logcom.service \
    %{buildroot}/%{_unitdir}/pagure_logcom.service

# Install the systemd file for the loadjson service
install -p -m 644 files/pagure_loadjson.service \
    %{buildroot}/%{_unitdir}/pagure_loadjson.service

# Install the systemd file for the mirror service
install -p -m 644 files/pagure_mirror.service \
    %{buildroot}/%{_unitdir}/pagure_mirror.service

# Install the systemd file for the script sending reminder about API key
# expiration
install -p -m 644 files/pagure_api_key_expire_mail.service \
    %{buildroot}/%{_unitdir}/pagure_api_key_expire_mail.service
install -p -m 644 files/pagure_api_key_expire_mail.timer \
    %{buildroot}/%{_unitdir}/pagure_api_key_expire_mail.timer

# Install the systemd file for the script updating mirrored project
install -p -m 644 files/pagure_mirror_project_in.service \
    %{buildroot}/%{_unitdir}/pagure_mirror_project_in.service
install -p -m 644 files/pagure_mirror_project_in.timer \
    %{buildroot}/%{_unitdir}/pagure_mirror_project_in.timer

# Install the milter files
mkdir -p %{buildroot}/%{_tmpfilesdir}
install -p -m 0644 pagure-milters/milter_tempfile.conf \
    %{buildroot}/%{_tmpfilesdir}/%{name}-milter.conf
install -p -m 644 pagure-milters/pagure_milter.service \
    %{buildroot}/%{_unitdir}/pagure_milter.service
install -p -m 644 pagure-milters/comment_email_milter.py \
    %{buildroot}/%{_datadir}/pagure/comment_email_milter.py

# Install the eventsource
mkdir -p %{buildroot}/%{_libexecdir}/pagure-ev
install -p -m 755 pagure-ev/pagure_stream_server.py \
    %{buildroot}/%{_libexecdir}/pagure-ev/pagure_stream_server.py
install -p -m 644 pagure-ev/pagure_ev.service \
    %{buildroot}/%{_unitdir}/pagure_ev.service

# Switch all systemd units to use the correct libexecdir
sed -e "s|/usr/libexec|%{_libexecdir}|g" -i %{buildroot}/%{_unitdir}/*.service

# Change default_config.py to use the correct libexecdir
sed -e "s|/usr/libexec|%{_libexecdir}|g" -i %{buildroot}/%{python3_sitelib}/pagure/default_config.py

# Fix the shebang for various scripts
sed -e "s|#!/usr/bin/env python|#!%{__python3}|" -i \
    %{buildroot}/%{_libexecdir}/pagure-ev/*.py \
    %{buildroot}/%{_libexecdir}/pagure/*.py \
    %{buildroot}/%{_datadir}/pagure/*.py \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/*.py \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/hookrunner \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/post-receive \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/pre-receive \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/repospannerhook

# Switch interpreter for systemd units to correct Python interpreter
sed -e "s|/usr/bin/python|%{__python3}|g" -i %{buildroot}/%{_unitdir}/*.service

# Make symlinks for default theme packages
mv %{buildroot}/%{python3_sitelib}/pagure/themes/default %{buildroot}/%{python3_sitelib}/pagure/themes/upstream
ln -sr %{buildroot}/%{python3_sitelib}/pagure/themes/upstream %{buildroot}/%{python3_sitelib}/pagure/themes/default
ln -sr %{buildroot}/%{python3_sitelib}/pagure/themes/chameleon %{buildroot}/%{python3_sitelib}/pagure/themes/default.openSUSE

# Run fdupes
%fdupes %{buildroot}/%{python3_sitelib}
%fdupes doc/_build/html

# Make log directory and files
mkdir -p %{buildroot}/%{_localstatedir}/log/pagure
logfiles="web docs_web"

for logfile in $logfiles; do
   touch %{buildroot}/%{_localstatedir}/log/pagure/access_${logfile}.log
   touch %{buildroot}/%{_localstatedir}/log/pagure/error_${logfile}.log
done

# Regenerate clobbered symlinks (Cf. https://pagure.io/pagure/issue/3782)
runnerhooks="post-receive pre-receive"

for runnerhook in $runnerhooks; do
   rm -rf %{buildroot}/%{python3_sitelib}/pagure/hooks/files/$runnerhook
   ln -sf hookrunner %{buildroot}/%{python3_sitelib}/pagure/hooks/files/$runnerhook
done

# Make the rcFOO symlinks for systemd services
mkdir -p %{buildroot}/%{_sbindir}
paguresvcs="api_key_expire_mail ci ev authorized_keys_worker gitolite_worker loadjson logcom milter mirror webhook worker mirror_project_in"
for paguresvc in $paguresvcs; do
   ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rcpagure_$paguresvc
done

# Install the basic directory structure
mkdir -p %{buildroot}/srv/www/pagure-releases
mkdir -p %{buildroot}/srv/gitolite/pseudo
mkdir -p %{buildroot}/srv/gitolite/repositories/{,docs,forks,requests,tickets}
mkdir -p %{buildroot}/srv/gitolite/remotes
mkdir -p %{buildroot}/srv/gitolite/.gitolite/{conf,keydir,logs}
mkdir -p %{buildroot}/srv/gitolite/.ssh

# Add empty gitolite config file
touch %{buildroot}/srv/gitolite/.gitolite/conf/gitolite.conf

# Install gitolite rc file
install -p -m 644 files/gitolite3.rc %{buildroot}/srv/gitolite/.gitolite.rc

%pre
# Do nothing, but ensure dependency is evaluated...

%post
echo "Create wsgi rundir if it doesn't exist..."
mkdir -p /srv/www/run || :

echo "See %{_docdir}/%{name}/README.SUSE to continue"
%systemd_post pagure_worker.service
%systemd_post pagure_authorized_keys_worker.service
%systemd_post pagure_gitolite_worker.service
%systemd_post pagure_api_key_expire_mail.timer
%systemd_post pagure_mirror_project_in.timer

%post web-nginx
%systemd_post pagure_web.service
%systemd_post pagure_docs_web.service

%post milters
%tmpfiles_create %{_tmpfilesdir}/%{name}-milter.conf
%systemd_post pagure_milter.service

%post ev
%systemd_post pagure_ev.service

%post webhook
%systemd_post pagure_webhook.service

%post ci
%systemd_post pagure_ci.service

%post logcom
%systemd_post pagure_logcom.service

%post loadjson
%systemd_post pagure_loadjson.service

%post mirror
%systemd_post pagure_mirror.service

%preun
%systemd_preun pagure_worker.service
%systemd_preun pagure_authorized_keys_worker.service
%systemd_preun pagure_gitolite_worker.service
%systemd_preun pagure_api_key_expire_mail.timer
%systemd_preun pagure_mirror_project_in.timer

%preun web-nginx
%systemd_preun pagure_web.service
%systemd_preun pagure_docs_web.service

%preun milters
%systemd_preun pagure_milter.service

%preun ev
%systemd_preun pagure_ev.service

%preun webhook
%systemd_preun pagure_webhook.service

%preun ci
%systemd_preun pagure_ci.service

%preun logcom
%systemd_preun pagure_logcom.service

%preun loadjson
%systemd_preun pagure_loadjson.service

%preun mirror
%systemd_preun pagure_mirror.service

%postun
%systemd_postun_with_restart pagure_worker.service
%systemd_postun_with_restart pagure_authorized_keys_worker.service
%systemd_postun_with_restart pagure_gitolite_worker.service
%systemd_postun pagure_api_key_expire_mail.timer
%systemd_postun pagure_mirror_project_in.timer

%postun web-nginx
%systemd_postun_with_restart pagure_web.service
%systemd_postun_with_restart pagure_docs_web.service

%postun milters
%systemd_postun_with_restart pagure_milter.service

%postun ev
%systemd_postun_with_restart pagure_ev.service

%postun webhook
%systemd_postun_with_restart pagure_webhook.service

%postun ci
%systemd_postun_with_restart pagure_ci.service

%postun logcom
%systemd_postun_with_restart pagure_logcom.service

%postun loadjson
%systemd_postun_with_restart pagure_loadjson.service

%postun mirror
%systemd_postun_with_restart pagure_mirror.service

%files
%doc README.SUSE README.rst UPGRADING.rst doc/_build/html files/gitolite3.rc files/pagure.cfg.sample
%license LICENSE
%config(noreplace) %{_sysconfdir}/pagure/pagure.cfg
%config(noreplace) %{_sysconfdir}/pagure/alembic.ini
%dir %{_sysconfdir}/pagure/
%dir %{_datadir}/pagure/
%{_datadir}/pagure/*.py*
%exclude %{_datadir}/pagure/comment_email_milter.py*
%{_datadir}/pagure/alembic/
%{_libexecdir}/pagure/
%{python3_sitelib}/pagure/
%exclude %{python3_sitelib}/pagure/themes/default
%exclude %{python3_sitelib}/pagure/themes/default.openSUSE
%exclude %{python3_sitelib}/pagure/themes/upstream
%exclude %{python3_sitelib}/pagure/themes/pagureio
%exclude %{python3_sitelib}/pagure/themes/srcfpo
%exclude %{python3_sitelib}/pagure/themes/chameleon
%{python3_sitelib}/pagure*.egg-info
%{_bindir}/pagure-admin
%{_unitdir}/pagure_worker.service
%{_unitdir}/pagure_authorized_keys_worker.service
%{_unitdir}/pagure_gitolite_worker.service
%{_unitdir}/pagure_api_key_expire_mail.service
%{_unitdir}/pagure_api_key_expire_mail.timer
%{_unitdir}/pagure_mirror_project_in.service
%{_unitdir}/pagure_mirror_project_in.timer
%{_sbindir}/rcpagure_api_key_expire_mail
%{_sbindir}/rcpagure_worker
%{_sbindir}/rcpagure_authorized_keys_worker
%{_sbindir}/rcpagure_gitolite_worker
%{_sbindir}/rcpagure_mirror_project_in
# Pagure data content
%attr(-,git,git) %dir /srv/gitolite/pseudo
%attr(-,git,git) %dir /srv/gitolite/remotes
%attr(-,git,git) %dir /srv/gitolite/repositories/{,docs,forks,requests,tickets}
%attr(-,git,git) %dir /srv/gitolite/.gitolite/{,conf,keydir,logs}
%attr(750,git,git) %dir /srv/gitolite/.ssh
%attr(-,git,git) %config(noreplace) /srv/gitolite/.gitolite/conf/gitolite.conf
%attr(-,git,git) %config(noreplace) /srv/gitolite/.gitolite.rc
%attr(-,git,git) %dir /srv/www/pagure-releases
%attr(-,git,git) %dir %{_localstatedir}/log/pagure

%files web-apache-httpd
%license LICENSE
%doc files/pagure-apache-httpd.conf
%config(noreplace) %{_sysconfdir}/apache2/vhosts.d/pagure.conf
%config(noreplace) %{_datadir}/pagure/*.wsgi

%files web-nginx
%license LICENSE
%doc files/pagure-nginx.conf
%config(noreplace) %{_sysconfdir}/nginx/vhosts.d/pagure.conf
%{_unitdir}/pagure_web.service
%{_unitdir}/pagure_docs_web.service
%ghost %{_localstatedir}/log/pagure/access_*.log
%ghost %{_localstatedir}/log/pagure/error_*.log

%files theme-upstream
%license LICENSE
%{python3_sitelib}/pagure/themes/upstream/

%files theme-pagureio
%license LICENSE
%{python3_sitelib}/pagure/themes/pagureio/

%files theme-srcfpo
%license LICENSE
%{python3_sitelib}/pagure/themes/srcfpo/

%files theme-chameleon
%license LICENSE
%{python3_sitelib}/pagure/themes/chameleon/

%files theme-default-upstream
%license LICENSE
%{python3_sitelib}/pagure/themes/default

%files theme-default-openSUSE
%license LICENSE
%{python3_sitelib}/pagure/themes/default.openSUSE

%files milters
%license LICENSE
%dir %{_datadir}/pagure/
%{_tmpfilesdir}/%{name}-milter.conf
%{_unitdir}/pagure_milter.service
%{_datadir}/pagure/comment_email_milter.py*
%{_sbindir}/rcpagure_milter

%files ev
%license LICENSE
%{_libexecdir}/pagure-ev/
%{_unitdir}/pagure_ev.service
%{_sbindir}/rcpagure_ev

%files webhook
%license LICENSE
%{_unitdir}/pagure_webhook.service
%{_sbindir}/rcpagure_webhook

%files ci
%license LICENSE
%{_unitdir}/pagure_ci.service
%{_sbindir}/rcpagure_ci

%files logcom
%license LICENSE
%{_unitdir}/pagure_logcom.service
%{_sbindir}/rcpagure_logcom

%files loadjson
%license LICENSE
%{_unitdir}/pagure_loadjson.service
%{_sbindir}/rcpagure_loadjson

%files mirror
%license LICENSE
%{_unitdir}/pagure_mirror.service
%{_sbindir}/rcpagure_mirror

%changelog
* Tue May  3 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 5.13.3
  + Warn users when a PR contains some characters
  + srcfpo theme:
    + Change "Packages" link to new packages website
    + left-align the lines in description
  + fas user url updated for new accounts system
  + Change fas link from admin.fp.o to accounts.fp.o
  + Remove message about 60 day key length
  + Escape $ to fix Jenkins interpolation warning
  + Fix another invalid <img> width/height attribute
  + Fix missing space before src in <script>
  + Remove duplicate class attribute from Clone dropdown
  + Fix invalid <img> height (no px is allowed here)
  + Add Translation status link on repo_info page at src.fp.o
  + Update fedmsg homepage
  + Add support for noggin with the FAS auth backend
  + Update collaborator access level descriptions
  + Fix a type, add missing work hand
  + Fix Pagure's overview page verbatim error
* Thu Sep 16 2021 Neal Gompa <ngompa13@gmail.com>
- Drop unused dependency on nose
* Fri Feb 12 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 5.13.2
  + Fix broken pagination of group API
  + Fixing the alias url in the examples
  + Pull in upstream fix for apostrophes from highlightjs-rpm-specfile
  + Improve logging when trying to interract with a git repo via http(s)
* Fri Jan 29 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 5.13.1
  + Add the api_project_hascommit endpoint to the API doc
  + Do not return a 500 error when the OpenID provider doesn't provide an email
  + Fix bug in the default hook
  + When failing to find a git repo, log where pagure looked
  + Get the default branch of the target repo when linking for new PR
  + Add an hascommit API endpoint
  + Fixing sample input and output for alias related api
  + Add missing API endpoints related to git aliases and re-order a little
  + Add support for chardet 4.0+
  + Fix support for cchardet
  + Make the token_id column of the commit_flags table nullable
* Thu Jan  7 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 5.12
  + Display real line numbers on pull request's diff view
  + Show the assignee's avatar on the board
  + Allow setting a status as closing even if the project has no close_status
  + Include the assignee in the list of people notified on a ticket/PR
  + Add orphaning reason on the dist-git theme
  + Adjust the way we generate humanized dates so we provide the humanized date
    as well as the actual date when hovering over
  + When a file a detected as a binary file, return the raw file
  + Allow using the modifyacl API endpoint to remove groups from a project
  + Add a note that repo_from* argument are mandatory in some situations when
    opening a Pull-Request from the API
  + Increase the list of running pagure instances in the documentation
  + Remove fenced code block when checking mention
  + Add support for using cchardet to detect files' encoding
  + Show the default branch in the project overview page
  + Send appropriate SMTP status codes and error messages in the milter.
  + Report an error if a message ID isn't recognized by the milter.
  + Add support for disabling user registration
  + Add a way to make the stats view on more than one year (if you know how to)
  + Encode the data passed onto the mail hook so it is of bytes type
  + Reverse out of order instructions for new repos
  + Split the list of branches into two lists active/inactive in dist-git
  + Rework the "My PR" page so it does not pull so many info at once
  + Include the date of the last mirroring process in the logs
  + Forward the username when updating the pull-request
  + Add pagination to group API
  + When returning the commits flags in the API, returned them by update date
  + Change the PR flag API endpoints to use commit flags
  + Only show the subscribers list on demand
  + Improve the message shown when a new mirrored project is created
  + When editing the issue's description sent the html of it to the SSE server
  + Add an update-acls action to pagure-admin
  + Add support for AAA system sending SSH keys encoded in base64
  + Allow deleting the master branch when it is not the default branch
  + Allow people with a fork to have a working drop-down for opening new PRs
  + Fix handling "false" when editing project's options via the API
  + Ensure a fork project has the same default branch as its parent
  + Allow to specify a default branch for all projects hosted on an instance
  + Add a notification for when a group is removed from a project
  + When checking if messages were sent via a rebase, do not run the git hooks
  + Make the API endpoint to update project's options accept JSON
  + Add a full_url to the JSON representation of our main objects
  + Ensure the author in git commit notifications follow the expected format
  + Add support for git branch aliases
  + Allow updating the target branch when editing a PR
- Drop upstreamed patches
  + Patch: 0001-api-project-Fix-handling-of-false.patch
  + Patch: 0001-Display-real-line-numbers-on-pull-request-s-diff-vie.patch
  + Patch: 0002-Show-the-assignee-s-avatar-on-the-board.patch
  + Patch: 0003-Allow-setting-a-status-as-closing-even-if-the-projec.patch
  + Patch: 0004-Include-the-assignee-in-the-list-of-people-notified-.patch
  + Patch: 0005-Introduce-the-collaborator_project_groups-mapping.patch
  + Patch: 0006-When-a-file-a-detected-as-a-binary-file-return-the-r.patch
  + Patch: 0007-Remove-fenced-code-block-when-checking-mention.patch
  + Patch: 0008-Add-support-for-using-cchardet-to-detect-files-encod.patch
  + Patch: 0009-Add-support-for-disabling-user-registration.patch
* Thu Dec  3 2020 Neal Gompa <ngompa13@gmail.com>
- Add proposed fix for setting project options via API
  + Patch: 0001-api-project-Fix-handling-of-false.patch
* Thu Sep 24 2020 Neal Gompa <ngompa13@gmail.com>
- Backport various fixes from upstream
  + Patch: 0001-Display-real-line-numbers-on-pull-request-s-diff-vie.patch
  + Patch: 0002-Show-the-assignee-s-avatar-on-the-board.patch
  + Patch: 0003-Allow-setting-a-status-as-closing-even-if-the-projec.patch
  + Patch: 0004-Include-the-assignee-in-the-list-of-people-notified-.patch
  + Patch: 0005-Introduce-the-collaborator_project_groups-mapping.patch
  + Patch: 0006-When-a-file-a-detected-as-a-binary-file-return-the-r.patch
  + Patch: 0007-Remove-fenced-code-block-when-checking-mention.patch
  + Patch: 0008-Add-support-for-using-cchardet-to-detect-files-encod.patch
  + Patch: 0009-Add-support-for-disabling-user-registration.patch
- Remove mandatory dependency on systemd to ease containerization
* Sun Aug 30 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 5.11.3
  + Fix the model around the boards so it works with mariadb/mysql
  + Add new endpoints to the API documentation
* Tue Aug  4 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 5.11.2
  + Allow having a dedicated logging configuration for the git hooks
  + Increase logging to the pagure_auth logger
  + Make work pagure-admin ensure-project-hooks when the target link exists but is
    broken
  + Change the project icon when the project is mirrored from an external source
  + Allow a theme or a blueprint to inject custom buttons in the navigation bar.
  + Add API endpoint to get a pull-request comment
  + Omit breaking original comment format in reply on pull-requests
  + Let the milter announce when it reject an email based on its address
  + Don't Let the milter process the email we send.
  + Add a collaborator level to projects
  + Allow setting the default git branch when creating projects via the API
  + Allow creating mirrored project from the API
  + Add the possibility to set the default branch at project creation
  + Add API endpoint to set the default git branch and expose it in an existing
    endpoint
  + Adjust the example configuration for logging to a file
  + Allow project-less API token with the "modify_project" ACL to update watchers
  + Add a new API endpoint to retrieve a commit's metadata/info
  + Add a new API endpoint allowing to delete a project
  + Add support for customizing the new issue page
  + Introducing the boards feature
  + Add an API endpoint to view the content of a git repo
  + Port pagure's markdown extension to the new API
  + Multiple small fixes for the vagrant-based development environment
  + Use WhiteNoise to serve static assets for the Pagure web
  + Fix the title of the graph showing the evolution of the number of open tickets
    on a project
  + Do not assume there is a SMTP_STARTTLS configuration key set
  + Bring back JS library used for the heatmap
  + Show the ACL name in addition to the description when creating API tokens
  + Allow editing the URL a project is mirrored from
  + Add comments to the mirror service files for clarifying their purpose.
  + Add a dedicated logger for everything that is auth related
  + api: fix apidoc format on api_view_issues_history_detailed_stats Fixes web
    api doc view template issues
  + doc: Add a page documenting known Pagure instances
  + starttls support via SMTP_STARTTLS: provide additional documentation.
  + Add support for smtp server requiring starttls to work
  + Make the stats page use the new stats API endpoint
- Drop patches included in this release
  + Patch: 0001-Make-the-stats-page-use-the-new-stats-API-endpoint.patch
  + Patch: 0001-Add-support-for-smtp-server-requiring-starttls-to-wo.patch
  + Patch: 0002-starttls-support-via-SMTP_STARTTLS-provide-additiona.patch
  + Patch: 0001-Do-not-assume-there-is-a-SMTP_STARTTLS-configuration.patch
  + Patch: 0001-Fix-repotype-spelling.patch
  + Patch: 0001-api-fix-apidoc-format-on-api_view_issues_history_det.patch
  + Patch: 0001-Allow-editing-the-URL-a-project-is-mirrored-from.patch
  + Patch: 0001-Show-the-ACL-name-in-addition-to-the-description-whe.patch
  + Patch: 0001-Bring-back-JS-library-used-for-the-heatmap.patch
  + Patch: 0001-Ensure-the-title-name-of-the-headers-are-strings.patch
  + Patch: 0001-Fix-the-title-of-the-graph-showing-the-evolution-of-.patch
  + Patch: 0001-Make-sure-authorized_keys-file-has-mode-600.patch
  + Patch: 0101-Use-WhiteNoise-to-serve-static-assets-for-the-Pagure.patch
* Sun Jun 21 2020 Neal Gompa <ngompa13@gmail.com>
- Backport fixes for STARTTLS support
  + Patch: 0002-starttls-support-via-SMTP_STARTTLS-provide-additiona.patch
  + Patch: 0001-Do-not-assume-there-is-a-SMTP_STARTTLS-configuration.patch
- Backport fix for docs repo access grant
  + Patch: 0001-Fix-repotype-spelling.patch
- Backport fix for visual bug on API docs formatting
  + Patch: 0001-api-fix-apidoc-format-on-api_view_issues_history_det.patch
- Backport fix to changing pull mirror settings
  + Patch: 0001-Allow-editing-the-URL-a-project-is-mirrored-from.patch
- Backport fix to add descriptions to API scopes
  + Patch: 0001-Show-the-ACL-name-in-addition-to-the-description-whe.patch
- Backport fix to make heatmap UI functional again
  + Patch: 0001-Bring-back-JS-library-used-for-the-heatmap.patch
- Backport fix for handling headers
  + Patch: 0001-Ensure-the-title-name-of-the-headers-are-strings.patch
- Backport fix for burndown graph title
  + Patch: 0001-Fix-the-title-of-the-graph-showing-the-evolution-of-.patch
- Backport fix for permissions on authorized_keys file
  + Patch: 0001-Make-sure-authorized_keys-file-has-mode-600.patch
- Add patch to use whitenoise for rendering static assets
  + Patch: 0101-Use-WhiteNoise-to-serve-static-assets-for-the-Pagure.patch
- Refresh default configuration patch
  + Patch: pagure-5.0-default-example-cfg.patch
* Wed May 20 2020 Neal Gompa <ngompa13@gmail.com>
- Fix typo in quickstart on ssh directory mode
- Backport support for STARTTLS support for SMTP servers
  + Patch: 0001-Add-support-for-smtp-server-requiring-starttls-to-wo.patch
* Mon May 18 2020 Neal Gompa <ngompa13@gmail.com>
- Backport fix from upstream to fix stats page
  + Patch: 0001-Make-the-stats-page-use-the-new-stats-API-endpoint.patch
- Add missing step to start pagure web services for nginx setup in quickstart
- Fix directory mode for ssh directory to fix conflict with gitolite
* Fri May 15 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 5.10.0
  + Allow viewing issues via the API using project-less API token
  + Various improvements to the srcfpo theme
  + Make pagure work with recent sqlalchemy versions (>= 1.3.0)
  + Add a new API endpoint to retrieve detailed stats about the issues
  + Improve the graphs displayed in the stats tab of each projects
  + Add a new graph tracking the number of open issues throughout the year
  + Improve loading tickets from git
  + Support pygit2 >= 1.1.0
  + Add missing endpoints to the API documentation
  + Add support for wtforms >= 2.3
  - Add dependency on email_validator in such case
  + Fix sorting users by their username when using python3
  + Correct the API documentation for updating the watchers of a project
  + Ensure the name of the headers are always of the correct type
    (especially when using python3)
  + Ensure aclchecker and keyhelper can work with APP_URL having a trailing slash
  + Add a new git auth backend which can manage the .ssh/authorized_keys file
    directly
  + Update information about supported Git auth backends
  + Add support for arrow >= 0.15.6
  + Fix getting the milter running with python3
  + Fix mirroring project hosted remotely
  + Add url_path property to class User (and thus in the API)
  + Improve email text for new user registration
  + Set the USER environment variable when pushing over http
  + Add support for git push via http using basic auth relying on API token
  + If pagure is set up for local auth, allow git push via https to use it
  + Add an example nginx configuration file for pagure
  + Create two subpackages in the pagure for the apache and nginx configuration
    files
  + Add some documentation on how git push over http works in pagure
  + Make pagure compatible with the latest version of flake8
  + Add PAGURE_PLUGINS_CONFIG setting in pagure configuration file
- Refresh quick start instructions for new configuration options
- Drop unneeded patch
  + Patch: 0501-Revert-Add-a-upper-limit-to-sqlalchemy.patch
- Refresh default configuration patch
  + Patch: pagure-5.0-default-example-cfg.patch
* Sat Apr  4 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 5.9.1
  + Add a missing div tag that broke the user's settings page
  + Do not block when waiting for subprocess to finish
  + Fix git blame when the identifier provided is a blob
  + Fix view_commits when the identified provided is a blob
  + When viewing file's history, use the default branch if needed
* Wed Mar 25 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 5.9.0
  + Add API to manage plugins (ie: git hooks)
  + Fix querying mdapi from within the srcfpo theme
  + Various fixes for the srcfpo theme
  + Multiple fixes and improvements to the API endpoints to retrieve the tags
    used in a project
  + Add new API endpoints to manipulate tags in projects
  + Add a new API endpoint to edit/update an existing issue/ticket
  + Add a new page to see a file's history in git (linked from the file's view page
    and the blame page)
  + Only consider the 6 most recently active branch in the drop-down to create
    new PR
  + Fix the view_commit endpoint when the identifier provided is a git tag
  + Add an endpoint to renew user API token
  + Include a link to where the token can be renewed in the email about API
    token nearing expiration
  + Allow users to set their own expiration date on API token (up to 2 years)
  + Fix the /groups API endpoint and order the output by group name
  + Add a new API endpoint to retrieve a project's webhook token
  + Expose related_prs on issue API
  + Fix the regenerate-repo actions
  + Provide some feedback to the user when changing monitoring worked
  + Hide the SSH clone URL if the user is not in one of the group with ssh
    access
  + Order pull requests based on updated_on column when we want to order based
    on last updated time
  + Fix taking into account the blacklisted patterns
  + Rework/fix the API documentation page
  + Allow deploy keys to commit to the doc git repository of a project
  + Increase a lot the logging when someone asks for access to a git repo
* Mon Dec  2 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.8.1
  + Fix the link to the container namespace in srcfpo
  + Fix checking if the user is a committer of the repo the PR originates from
  + Fix showing the origin of the PR when it originates from the same project
  + Do not hard-code UTF-8 when showing a file
* Sat Nov 16 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.8
  + Enable the ctrl-enter keys to submit forms on tickets and PRs
  + Fix spelling errors on documentation
  + Fix renewing url on invalid token error message
  + Various fixes to the srcfpo theme
  + disable smooth scrolling on initial highlight & scroll process
  + Accept a with_commits parameter on the branches api to resolve the HEAD commits
  + Various fixes to the PR view
  + Add support for arrow >= 0.15
  + Select full text on git|ssh url input boxes when they get focus
  + Send notification when a branch is created
  + Add revision along with tag/branch creation/deletion
  + Add asciidoc syntax override
  + Fix git blame on unborn HEAD or non-master default branch repos
  + Fix the logic to rebase PRs
  + Fix setting one's default email address
  + Send oldrev as old_commit for git.receive event
  + Add a set-default-branch action to pagure-admin
  + Fix rendering badges on the PR list page
  + Tweak when we show the merge and the rebase buttons
  + Fix the logic around interacting with read-only databases in hooks
  + Fix .diff and .patch generation for empty commits
  + Fix url on the invalid token error message
  + Fix typo on the pull request merge error message
  + Allow cross-project API token to open pull-request
  + Allow updating PRs via the API using cross-project tokens
  + Fix the logic to make the merge button appear on pull-request
* Sun Aug 11 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.7.4
  + Add more administrative functions to pagure_admin
  + Add CSP headers support and a mechanism to customize them
  + Do not allow rebase via the API if the PR does not allow it
  + Allow project-less API token to retrieve issues via the API
  + Improve the support for spec file highlighting
- Drop patch that is part of this release
  + 0001-Couple-of-fixes-for-the-mirroring-in-feature.patch
* Tue Apr  9 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.5
  + Add support for !owner to the API listing projects
  + Make sure that TemporaryClone.push also pushes tags
  + Various UI improvements
  + Allow blocking an user on a project
  + Replace calls to pygit2.clone_repository by calls to git clone directly
  + Make fork more performant by using 'git push --mirror'
  + Use the user's default email when rebasing
- Drop patch that is part of this release
  + 0001-pagure-ev-python-3-compatibility.patch
- Backport fix for pull mirroring service
  + 0001-Couple-of-fixes-for-the-mirroring-in-feature.patch
* Fri Mar 29 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.4
  + Allow by default the ACL "pull_request_create" on project-less API token
  + Implement Pagure Git Auth
  + Add a new API endpoint allowing to update an existing PR
  + If the user doesn't have a valid ssh key inform but let them log in
  + Fix various UI issues
  + Add a button to take/drop a pull-request
  + Add a new API endpoint to assign pull-request to someone
  + Allow dots and plus signs in project names
  + Fix seeing releases when the reference provided returned a commit
  + Include the PR tags in their JSON representation
  + Ensure that forking does not run the hook
  + Deprecate fedmsg for fedora-messaging
- Backport fix for pagure-ev issues in Python 3
  + Patch: 0001-pagure-ev-python-3-compatibility.patch
- Add patch to allow SQLAlchemy 1.3.0+ with Pagure
  + Patch: 0501-Revert-Add-a-upper-limit-to-sqlalchemy.patch
- Update the service list to enable and start in README.SUSE
* Fri Feb 22 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.3
  + Add support for AMQP via fedora-messaging
  + Improve filtering and searching through issues and PRs
  + Add support for forcing highlight types based on file extensions
  + Fix naming rules for labels/tags
  + Fix support for repoSpanner Git storage backend
  + CVE-2019-7628: Do not leak partial API keys in key expiration emails (boo#1124762)
- Drop patches that are part of this release
  + 0001-Allow-using-Pagure-with-python-redis-3.0.0.patch
  + 0002-Fix-Markdown-usage-to-work-with-Markdown-3.0.patch
* Sat Jan 12 2019 Jan Engelhardt <jengelh@inai.de>
- Replace old $RPM_* shell vars.
* Thu Jan 10 2019 Neal Gompa <ngompa13@gmail.com>
- Update to 5.2
  + Add support for the MQTT protocol
  + Add support for mirroring in git repositories from outside sources
  + Add support to merge a PR when the fork was deleted
  + Add the ability to generate archive from a commit or tag
  + Allow searching the content of the comments on an issue tracker
  + Allow filtering the issue list by the close status
  + Show related PRs on the issue list if there are any
  + Add build status to pull requests page
  + Add new API endpoints for get and set project options
  + Add WIP/experimental/unstable support for third-party extensions to pagure
  + Add support for rebasing pull-requests
  + Implement a button to rerun CI tests on a pull request
  + Support disallowing remote pull requests
  + Add an about page in the themes
  + Update the chameleon theme
- Backport fix from master to allow using python-redis >= 3.0.0
  + Patch: 0001-Allow-using-Pagure-with-python-redis-3.0.0.patch
- Backport fix from master to fix compatibility with Markdown 3.0+
  + Patch: 0002-Fix-Markdown-usage-to-work-with-Markdown-3.0.patch
- Drop patches that are part of this release
  + 0001-Port-pagure-to-markdown-3.0-while-remaining-backward.patch
  + 0002-Bypass-old-hooks-rather-than-using-non-existing-syml.patch
* Thu Dec 13 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 5.1.4
  + Fix the alembic migration creating the hook_mirror table
  + Close the DB session in one place for all hooks
  + Add more logging to the pagure_logcom service
  + Configure SMTP info for git_multimail
  + Use the PR UID previously read from environment
- Backport fix from master to add compatibility with Markdown 3.0+
  + Patch: 0001-Port-pagure-to-markdown-3.0-while-remaining-backward.patch
- Backport fix from master to properly skip legacy hooks
  + Patch: 0002-Bypass-old-hooks-rather-than-using-non-existing-syml.patch
* Thu Oct 11 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 5.1.3
  + Don't sync up ssh keys if there are already some
  + Do not notify twice when pushing commits to an open PR
  + Update git-multimail to fix it for Python 3
* Thu Oct 11 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 5.1.2
  + Make the sshkey migration more flexible from < 5.1
  + Fix the update date information on the pull-request page
  + Fix detecting if the user is a committer via a group
  + Fix writing user's ssh keys on disk
  + tweak colors of the activity graph
  + cache oidc user data
* Tue Oct  9 2018 Neal Gompa <ngompa13@gmail.com>
- Invert Conflicts to Requires OpenSSH >= 7.4
* Tue Oct  9 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 5.1.1
  + Fix adding and removing ssh keys in the user's profile
* Tue Oct  9 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 5.1
  + Multiple fixes to the UI to address visual quirks and glitches
  + Initial implementation of HTTP(S) push support
  + Rework how SSH keys are stored in the database
  + Multiple changes and fixes around the ACL checker
  + Adding 'list-groups' function to pagure-admin
  + Add a new API endpoint to retrieve the list of files changed in a PR
- Add Conflicts for OpenSSH < 7.4 due to SSH key handling rework
- Re-wrap previous changelog entry for readability
* Tue Oct  2 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
- Replace old $RPM_* shell vars by macros.
- Update summaries to include those are Pagure themes.
* Sun Sep 30 2018 Neal Gompa <ngompa13@gmail.com>
- Add missing directory to directory structure
* Sat Sep 29 2018 Neal Gompa <ngompa13@gmail.com>
- Drop unnecessary systemd build dependency
* Sat Sep 29 2018 Neal Gompa <ngompa13@gmail.com>
- Add missing rcFOO symlinks to systemd services
* Sat Sep 29 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 5.0.1
  + Multiple adjustments to the scripts keyhelper and aclchecker
  + Only enforce Signed-Off-By on the code repo of a project
  + Sign-off the merge commits when the project enforces it
  + Switch from GIT_SORT_TIME to GIT_SORT_NONE to preserve
    'git log'-like commit ordering
  + Add reporter and assignee to notification emails headers
  + Fix various visual glitches
- Restore symlinks clobbered by setuptools' creation of archive
* Mon Sep 24 2018 Neal Gompa <ngompa13@gmail.com>
- Rebase to 5.0
  + Pagure now runs on Python 3
  + The UI has been completely redesigned
  + Theming has been redesigned, and new themes are included as subpackages
  + Many new API endpoints have been added
  + Rework how git hooks work to rely on a single file for efficiency
  + Expanded functionality included in the pagure-admin command
- Pagure defaults to the chameleon theme for openSUSE
- Drop all upstreamed patches
- Refresh example configuration patch
* Sun Jul 22 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 4.0.4
- Refresh config fix patch for pagure-milters
* Wed Jul 11 2018 Neal Gompa <ngompa13@gmail.com>
- Add missing requirement on python-Pillow
* Wed Jul 11 2018 Neal Gompa <ngompa13@gmail.com>
- Drop python2-trollius-redis requirement since it's not actually used
* Sun Jun 10 2018 Neal Gompa <ngompa13@gmail.com>
- Backport patch to make syntax highlighting threshold configurable
* Sat Jun  9 2018 Neal Gompa <ngompa13@gmail.com>
- Bundle an internal pagure-celery binary to use stock celery
  with Python 2
- Switch to a sed call instead of a patch to fix systemd units
  to use correct libexecdir
* Sat Jun  9 2018 Neal Gompa <ngompa13@gmail.com>
- Fix syntax error in gitolite3.rc file
* Fri Jun  8 2018 Neal Gompa <ngompa13@gmail.com>
- Switch from /srv/pagure to /srv/gitolite to use the already
  setup gitolite directory structure
* Mon Jun  4 2018 Neal Gompa <ngompa13@gmail.com>
- Fix pagure-ev to use correct libexecdir
- Fix pagure-milters to call correct function to load config
* Mon Jun  4 2018 Neal Gompa <ngompa13@gmail.com>
- Install gitolite configuration
* Mon Jun  4 2018 Neal Gompa <ngompa13@gmail.com>
- Prepare more of the filesystem tree as part of the packaging
- Refine README.SUSE to more closely match the required steps
* Sat Jun  2 2018 Neal Gompa <ngompa13@gmail.com>
- Refresh configuration patch to match SUSE sematics
- Add README.SUSE file for basic setup quick start guide
* Mon May 28 2018 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Mageia packaging
